@@ -2,8 +2,8 @@
 //! This package was created for people who absolutely hate writing Javascript.
 //! The goal of this library is to reduce the amount of overhead required to implement
 //! WASM by automatically compiling WASM modules and statically linking them to
-//! the your binary. You will need to have [wasm-bindgen](https://developer.mozilla.org/en-US/docs/WebAssembly/Rust_to_wasm) installed.
-//! If your project stops building, please submit an issue.
+//! your binary. You will need to have [wasm-bindgen](https://developer.mozilla.org/en-US/docs/WebAssembly/Rust_to_wasm) installed.
+//! If your project stops building, please submit an issue. You may also try deleting .wasmir directory.
 
 //! # Usage
 //! Code must be declared inside a module. The typical usage is as follows:
@@ -28,8 +28,18 @@
 //! }
 //! ```
 //! Once the proc_macro does its work, the above module will then contain two binary blob constants,
-//! `wasm` and `js_loader`. It is important that `js_loader` is served with your web app (inside index.html) and that the
-//! wasm binary is served at the correct address of "./my_module_bg.wasm"
+//! `wasm` and `loader`. Serve loader from "my_module.js" and wasm from "my_module_bg.wasm"
+//! Then, in index.js, include the following code:
+//! ```js
+//! import init from './my_module_bg.js';
+//! import {greet} from './my_module_bg.js';
+//! 
+//! function run() {
+//!    greet(\"World\");
+//! }
+//! 
+//! init().then(run)
+//! ```
 
 // Macro gets applied to module, function, struct, etc.
 // Macro calls compiler with web assembly target on code.
@@ -91,16 +101,16 @@ pub fn wasmir(_attr: TokenStream, input: TokenStream) -> TokenStream {
 		.arg(module_name.clone())
 		.output()
 	{
-		Ok(_) => {}
-		Err(_) => {
-			// attempt to write to lib.rs in module root
-			let mut file = File::open(module_root.join("src").join("lib.rs"))
-				.expect("could not open lib.rs for editing");
-			let buf: Vec<u8> = module_text.as_bytes().iter().map(|b| *b).collect();
-			file.write_all(&buf).expect("could not write to lib.rs");
-		}
+		Ok(o) => {println!["{:#?}", o];}
+		Err(_) => {}
 	};
 
+	// attempt to write to lib.rs in module root
+	let mut file = File::create(module_root.join("src").join("lib.rs"))
+		.expect("could not open lib.rs for editing");
+	let buf: Vec<u8> = module_text.as_bytes().iter().map(|b| *b).collect();
+	file.write_all(&buf).expect("could not write to lib.rs");
+
 	// Configure the module
 	let mut buf = String::new();
 	let mut file = OpenOptions::new()
@@ -162,9 +172,7 @@ pub fn wasmir(_attr: TokenStream, input: TokenStream) -> TokenStream {
 		.arg("web")
 		.output()
 	{
-		Ok(o) => {
-			println!["{:?}", o];
-		}
+		Ok(o) => {println!["{:#?}", o];}
 		Err(e) => {
 			panic!["could not build: {}", e];
 		}
@@ -195,19 +203,16 @@ pub fn wasmir(_attr: TokenStream, input: TokenStream) -> TokenStream {
 		Err(e) => panic!["could not open js: {}", e],
 	};
 
-	let mut js = vec![];
+	let mut js = String::new();
 
-	file.read_to_end(&mut js).expect("could not read-in js");
-
-	let js_len = js.len();
+	file.read_to_string(&mut js).expect("could not read-in js");
 
 	let module_name = Ident::new(module_name.as_str(), Span::call_site());
 
 	quote![
-	mod #module_name {
-	  const wasm: [u8; #binary_len] = [#(#binary),*];
-	 const js_loader: [u8; #js_len] = [#(#js),*];
-	  }
-	]
+	 mod #module_name {
+		pub const wasm: [u8; #binary_len] = [#(#binary),*];
+		pub const loader: &str = #js;
+	}]
 	.into()
 }
